@@ -4,7 +4,7 @@
 
 extern void F77_NAME(momorif)(double*, int*, double*, int*, double*, double*, int*, int*, double*, double*, double*, double*, double*, double*, double*, double*, double*, double*, double*, int*, double*, double*, double*, double*, int*, int*);
 
-SEXP momori(SEXP y, SEXP n, SEXP pai, SEXP np, SEXP zts, SEXP zte, SEXP ncount, SEXP nfunct, SEXP nlmax)
+SEXP MomoriC(SEXP y, SEXP n, SEXP pai, SEXP np, SEXP zts, SEXP zte, SEXP ncount, SEXP nfunct, SEXP nlmax)
 {
     double *d1,*d2,*d3,*d4,*d5,*d6,*d7,*d8,*d9,*d10,*d11,*d12,*d13,*d14,*d15,*d16,*d17,*d18, *d19;
     int *i1,*i2,*i3,*i4,*i5,*i6,*i7;
